<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xqts="http://www.w3.org/2005/02/query-test-XQTSCatalog">
  
  <xsl:variable name="xqpath" select="'Queries/XQuery/'"/>
  <xsl:variable name="respath" select="'ExpectedTestResults/'"/>
  
  <xsl:output name="testdoc" method="xml" indent="yes"
    doctype-system="../../../src/unittests/com/xhive/xquerytests/dtd/xquery_tests.dtd"/>
    
  <xsl:template match="/">
    <xsl:apply-templates select="//xqts:test-group[@name =
      ('MinimalConformance','FullAxis', 'UseCase', 'Catalog', 'Modules')]//xqts:test-group[not(empty(xqts:test-case))]"/>
  </xsl:template>
    
  <xsl:template match="xqts:test-group">
    <xsl:result-document href="{ @name }.xml" format="testdoc">
      <xquery-tests name="{ @name }">
        <resourceLocation>../src/conformance/</resourceLocation>
        <xsl:for-each select="for $docid in distinct-values(xqts:test-case/xqts:input-file) return
          /xqts:test-suite/xqts:sources/xqts:source[@ID = $docid]/@FileName">
          <document>
            <file>
              <xsl:value-of select="."/>
            </file>
          </document>
        </xsl:for-each>
        <xsl:apply-templates select="xqts:test-case"/>
      </xquery-tests>
    </xsl:result-document>
  </xsl:template>
  
  <xsl:template name="singletest" match="xqts:test-case">
    <xsl:variable name="querybasepath" select="concat($xqpath,@FilePath)"/>
    <xsl:variable name="resultbasepath" select="concat($respath,@FilePath)"/>
    <test name="{ @name }">
      
      <xsl:comment select="concat('Retrieved from ',concat($querybasepath, string((./xqts:query/@name)[1])))"></xsl:comment>
      
      <description>
        <xsl:copy-of select="./xqts:description/child::node()"/>
      </description>
      <query><xsl:value-of select="unparsed-text(concat($querybasepath, string((./xqts:query/@name)[1])), 'UTF-8')"/></query>
      <xsl:for-each select="xqts:input-file">
        <param name="{@variable}">getDatabase().getRoot().executeXQuery(&quot;document(&apos;<xsl:value-of select="for $docid in ./text() return substring-after(string(/xqts:test-suite/xqts:sources/xqts:source[@ID = $docid]/@FileName), '/')"></xsl:value-of>&apos;)&quot;)</param>
      </xsl:for-each>
      <xsl:choose>
        <xsl:when test="./xqts:output-file">
          <xsl:value-of select="'&#xA;'"/>
          <xsl:comment select="concat('Retrieved from ',concat($resultbasepath,string(./xqts:output-file[1])))"></xsl:comment>
          <xsl:value-of select="'&#xA;'"/>
          <serializedResult compare="{./xqts:output-file/@compare}">
              <xsl:value-of select="
                unparsed-text(concat($resultbasepath,
                string(./xqts:output-file[1])), 'UTF-8')"/>
          </serializedResult>
        </xsl:when>
        <xsl:when test="./xqts:expected-error">
          <xsl:apply-templates select="xqts:expected-error"/>
        </xsl:when>
      </xsl:choose>
    </test>
  </xsl:template>
  
  <xsl:template match='xqts:expected-error'>
    <xsl:choose>
      <xsl:when test="text() = 'XPST0003'">
        <exception type='XHIVE' code="XQUERY_PARSE_ERROR"/>
      </xsl:when>
      <xsl:when test="text() = ('XQDY0004')">
        <exception type='DOM'/>
      </xsl:when>
      <!--xsl:when test="text() = ('XPST0008')">
        <exception type='XHIVE' code="XQUERY_PARSE_ERROR"/>
      </xsl:when-->
      <xsl:otherwise>
        <exception type='XHIVE' code="XQUERY_ERROR_VALUE"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
 
</xsl:stylesheet>
